# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['AppSamlAppSettingsArgs', 'AppSamlAppSettings']

@pulumi.input_type
class AppSamlAppSettingsArgs:
    def __init__(__self__, *,
                 app_id: pulumi.Input[builtins.str],
                 settings: pulumi.Input[builtins.str]):
        """
        The set of arguments for constructing a AppSamlAppSettings resource.
        :param pulumi.Input[builtins.str] app_id: ID of the application.
        :param pulumi.Input[builtins.str] settings: Application settings in JSON format
        """
        pulumi.set(__self__, "app_id", app_id)
        pulumi.set(__self__, "settings", settings)

    @property
    @pulumi.getter(name="appId")
    def app_id(self) -> pulumi.Input[builtins.str]:
        """
        ID of the application.
        """
        return pulumi.get(self, "app_id")

    @app_id.setter
    def app_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "app_id", value)

    @property
    @pulumi.getter
    def settings(self) -> pulumi.Input[builtins.str]:
        """
        Application settings in JSON format
        """
        return pulumi.get(self, "settings")

    @settings.setter
    def settings(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "settings", value)


@pulumi.input_type
class _AppSamlAppSettingsState:
    def __init__(__self__, *,
                 app_id: Optional[pulumi.Input[builtins.str]] = None,
                 settings: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering AppSamlAppSettings resources.
        :param pulumi.Input[builtins.str] app_id: ID of the application.
        :param pulumi.Input[builtins.str] settings: Application settings in JSON format
        """
        if app_id is not None:
            pulumi.set(__self__, "app_id", app_id)
        if settings is not None:
            pulumi.set(__self__, "settings", settings)

    @property
    @pulumi.getter(name="appId")
    def app_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ID of the application.
        """
        return pulumi.get(self, "app_id")

    @app_id.setter
    def app_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "app_id", value)

    @property
    @pulumi.getter
    def settings(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Application settings in JSON format
        """
        return pulumi.get(self, "settings")

    @settings.setter
    def settings(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "settings", value)


@pulumi.type_token("okta:index/appSamlAppSettings:AppSamlAppSettings")
class AppSamlAppSettings(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_id: Optional[pulumi.Input[builtins.str]] = None,
                 settings: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Manages app settings of the SAML application.
        This resource allows you to manage app settings of the SAML Application . It's basically the same as
        app_settings_json field in app.Saml resource and can be used in cases where settings require to be managed separately.

        ## Example Usage

        ```python
        import pulumi
        import json
        import pulumi_okta as okta

        test = okta.app.Saml("test",
            preconfigured_app="amazon_aws",
            label="Amazon AWS",
            status="ACTIVE")
        test_app_saml_app_settings = okta.AppSamlAppSettings("test",
            app_id=test.id,
            settings=json.dumps({
                "appFilter": "okta",
                "awsEnvironmentType": "aws.amazon",
                "groupFilter": "aws_(?{{accountid}}\\\\\\\\d+)_(?{{role}}[a-zA-Z0-9+=,.@\\\\\\\\-_]+)",
                "joinAllRoles": False,
                "loginURL": "https://console.aws.amazon.com/ec2/home",
                "roleValuePattern": "arn:aws:iam::${accountid}:saml-provider/OKTA,arn:aws:iam::${accountid}:role/${role}",
                "sessionDuration": 3200,
                "useGroupMapping": False,
            }))
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/appSamlAppSettings:AppSamlAppSettings example <app_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] app_id: ID of the application.
        :param pulumi.Input[builtins.str] settings: Application settings in JSON format
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AppSamlAppSettingsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages app settings of the SAML application.
        This resource allows you to manage app settings of the SAML Application . It's basically the same as
        app_settings_json field in app.Saml resource and can be used in cases where settings require to be managed separately.

        ## Example Usage

        ```python
        import pulumi
        import json
        import pulumi_okta as okta

        test = okta.app.Saml("test",
            preconfigured_app="amazon_aws",
            label="Amazon AWS",
            status="ACTIVE")
        test_app_saml_app_settings = okta.AppSamlAppSettings("test",
            app_id=test.id,
            settings=json.dumps({
                "appFilter": "okta",
                "awsEnvironmentType": "aws.amazon",
                "groupFilter": "aws_(?{{accountid}}\\\\\\\\d+)_(?{{role}}[a-zA-Z0-9+=,.@\\\\\\\\-_]+)",
                "joinAllRoles": False,
                "loginURL": "https://console.aws.amazon.com/ec2/home",
                "roleValuePattern": "arn:aws:iam::${accountid}:saml-provider/OKTA,arn:aws:iam::${accountid}:role/${role}",
                "sessionDuration": 3200,
                "useGroupMapping": False,
            }))
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/appSamlAppSettings:AppSamlAppSettings example <app_id>
        ```

        :param str resource_name: The name of the resource.
        :param AppSamlAppSettingsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AppSamlAppSettingsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_id: Optional[pulumi.Input[builtins.str]] = None,
                 settings: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AppSamlAppSettingsArgs.__new__(AppSamlAppSettingsArgs)

            if app_id is None and not opts.urn:
                raise TypeError("Missing required property 'app_id'")
            __props__.__dict__["app_id"] = app_id
            if settings is None and not opts.urn:
                raise TypeError("Missing required property 'settings'")
            __props__.__dict__["settings"] = settings
        super(AppSamlAppSettings, __self__).__init__(
            'okta:index/appSamlAppSettings:AppSamlAppSettings',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            app_id: Optional[pulumi.Input[builtins.str]] = None,
            settings: Optional[pulumi.Input[builtins.str]] = None) -> 'AppSamlAppSettings':
        """
        Get an existing AppSamlAppSettings resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] app_id: ID of the application.
        :param pulumi.Input[builtins.str] settings: Application settings in JSON format
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AppSamlAppSettingsState.__new__(_AppSamlAppSettingsState)

        __props__.__dict__["app_id"] = app_id
        __props__.__dict__["settings"] = settings
        return AppSamlAppSettings(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="appId")
    def app_id(self) -> pulumi.Output[builtins.str]:
        """
        ID of the application.
        """
        return pulumi.get(self, "app_id")

    @property
    @pulumi.getter
    def settings(self) -> pulumi.Output[builtins.str]:
        """
        Application settings in JSON format
        """
        return pulumi.get(self, "settings")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['LinkDefinitionArgs', 'LinkDefinition']

@pulumi.input_type
class LinkDefinitionArgs:
    def __init__(__self__, *,
                 associated_description: pulumi.Input[builtins.str],
                 associated_name: pulumi.Input[builtins.str],
                 associated_title: pulumi.Input[builtins.str],
                 primary_description: pulumi.Input[builtins.str],
                 primary_name: pulumi.Input[builtins.str],
                 primary_title: pulumi.Input[builtins.str]):
        """
        The set of arguments for constructing a LinkDefinition resource.
        :param pulumi.Input[builtins.str] associated_description: Description of the associated relationship.
        :param pulumi.Input[builtins.str] associated_name: API name of the associated link.
        :param pulumi.Input[builtins.str] associated_title: Display name of the associated link.
        :param pulumi.Input[builtins.str] primary_description: Description of the primary relationship.
        :param pulumi.Input[builtins.str] primary_name: API name of the primary link.
        :param pulumi.Input[builtins.str] primary_title: Display name of the primary link.
        """
        pulumi.set(__self__, "associated_description", associated_description)
        pulumi.set(__self__, "associated_name", associated_name)
        pulumi.set(__self__, "associated_title", associated_title)
        pulumi.set(__self__, "primary_description", primary_description)
        pulumi.set(__self__, "primary_name", primary_name)
        pulumi.set(__self__, "primary_title", primary_title)

    @property
    @pulumi.getter(name="associatedDescription")
    def associated_description(self) -> pulumi.Input[builtins.str]:
        """
        Description of the associated relationship.
        """
        return pulumi.get(self, "associated_description")

    @associated_description.setter
    def associated_description(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "associated_description", value)

    @property
    @pulumi.getter(name="associatedName")
    def associated_name(self) -> pulumi.Input[builtins.str]:
        """
        API name of the associated link.
        """
        return pulumi.get(self, "associated_name")

    @associated_name.setter
    def associated_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "associated_name", value)

    @property
    @pulumi.getter(name="associatedTitle")
    def associated_title(self) -> pulumi.Input[builtins.str]:
        """
        Display name of the associated link.
        """
        return pulumi.get(self, "associated_title")

    @associated_title.setter
    def associated_title(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "associated_title", value)

    @property
    @pulumi.getter(name="primaryDescription")
    def primary_description(self) -> pulumi.Input[builtins.str]:
        """
        Description of the primary relationship.
        """
        return pulumi.get(self, "primary_description")

    @primary_description.setter
    def primary_description(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "primary_description", value)

    @property
    @pulumi.getter(name="primaryName")
    def primary_name(self) -> pulumi.Input[builtins.str]:
        """
        API name of the primary link.
        """
        return pulumi.get(self, "primary_name")

    @primary_name.setter
    def primary_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "primary_name", value)

    @property
    @pulumi.getter(name="primaryTitle")
    def primary_title(self) -> pulumi.Input[builtins.str]:
        """
        Display name of the primary link.
        """
        return pulumi.get(self, "primary_title")

    @primary_title.setter
    def primary_title(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "primary_title", value)


@pulumi.input_type
class _LinkDefinitionState:
    def __init__(__self__, *,
                 associated_description: Optional[pulumi.Input[builtins.str]] = None,
                 associated_name: Optional[pulumi.Input[builtins.str]] = None,
                 associated_title: Optional[pulumi.Input[builtins.str]] = None,
                 primary_description: Optional[pulumi.Input[builtins.str]] = None,
                 primary_name: Optional[pulumi.Input[builtins.str]] = None,
                 primary_title: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering LinkDefinition resources.
        :param pulumi.Input[builtins.str] associated_description: Description of the associated relationship.
        :param pulumi.Input[builtins.str] associated_name: API name of the associated link.
        :param pulumi.Input[builtins.str] associated_title: Display name of the associated link.
        :param pulumi.Input[builtins.str] primary_description: Description of the primary relationship.
        :param pulumi.Input[builtins.str] primary_name: API name of the primary link.
        :param pulumi.Input[builtins.str] primary_title: Display name of the primary link.
        """
        if associated_description is not None:
            pulumi.set(__self__, "associated_description", associated_description)
        if associated_name is not None:
            pulumi.set(__self__, "associated_name", associated_name)
        if associated_title is not None:
            pulumi.set(__self__, "associated_title", associated_title)
        if primary_description is not None:
            pulumi.set(__self__, "primary_description", primary_description)
        if primary_name is not None:
            pulumi.set(__self__, "primary_name", primary_name)
        if primary_title is not None:
            pulumi.set(__self__, "primary_title", primary_title)

    @property
    @pulumi.getter(name="associatedDescription")
    def associated_description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Description of the associated relationship.
        """
        return pulumi.get(self, "associated_description")

    @associated_description.setter
    def associated_description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "associated_description", value)

    @property
    @pulumi.getter(name="associatedName")
    def associated_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        API name of the associated link.
        """
        return pulumi.get(self, "associated_name")

    @associated_name.setter
    def associated_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "associated_name", value)

    @property
    @pulumi.getter(name="associatedTitle")
    def associated_title(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Display name of the associated link.
        """
        return pulumi.get(self, "associated_title")

    @associated_title.setter
    def associated_title(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "associated_title", value)

    @property
    @pulumi.getter(name="primaryDescription")
    def primary_description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Description of the primary relationship.
        """
        return pulumi.get(self, "primary_description")

    @primary_description.setter
    def primary_description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "primary_description", value)

    @property
    @pulumi.getter(name="primaryName")
    def primary_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        API name of the primary link.
        """
        return pulumi.get(self, "primary_name")

    @primary_name.setter
    def primary_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "primary_name", value)

    @property
    @pulumi.getter(name="primaryTitle")
    def primary_title(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Display name of the primary link.
        """
        return pulumi.get(self, "primary_title")

    @primary_title.setter
    def primary_title(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "primary_title", value)


@pulumi.type_token("okta:index/linkDefinition:LinkDefinition")
class LinkDefinition(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 associated_description: Optional[pulumi.Input[builtins.str]] = None,
                 associated_name: Optional[pulumi.Input[builtins.str]] = None,
                 associated_title: Optional[pulumi.Input[builtins.str]] = None,
                 primary_description: Optional[pulumi.Input[builtins.str]] = None,
                 primary_name: Optional[pulumi.Input[builtins.str]] = None,
                 primary_title: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Manages the creation and removal of the link definitions.

        Link definition operations allow you to manage the creation and removal of the link definitions. If you remove a link
        definition, links based on that definition are unavailable. Note that this resource is immutable, thus can not be modified.
        > **NOTE:** Links reappear if you recreate the definition. However, Okta is likely to change this behavior so that links don't reappear. Don't rely on this behavior in production environments.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.LinkDefinition("example",
            primary_name="emperor",
            primary_title="Emperor",
            primary_description="Hereditary ruler of the Imperium and the Known Universe",
            associated_name="sardaukar",
            associated_title="Sardaukar",
            associated_description="Elite military force member")
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/linkDefinition:LinkDefinition example <primary_name>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] associated_description: Description of the associated relationship.
        :param pulumi.Input[builtins.str] associated_name: API name of the associated link.
        :param pulumi.Input[builtins.str] associated_title: Display name of the associated link.
        :param pulumi.Input[builtins.str] primary_description: Description of the primary relationship.
        :param pulumi.Input[builtins.str] primary_name: API name of the primary link.
        :param pulumi.Input[builtins.str] primary_title: Display name of the primary link.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: LinkDefinitionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages the creation and removal of the link definitions.

        Link definition operations allow you to manage the creation and removal of the link definitions. If you remove a link
        definition, links based on that definition are unavailable. Note that this resource is immutable, thus can not be modified.
        > **NOTE:** Links reappear if you recreate the definition. However, Okta is likely to change this behavior so that links don't reappear. Don't rely on this behavior in production environments.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.LinkDefinition("example",
            primary_name="emperor",
            primary_title="Emperor",
            primary_description="Hereditary ruler of the Imperium and the Known Universe",
            associated_name="sardaukar",
            associated_title="Sardaukar",
            associated_description="Elite military force member")
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/linkDefinition:LinkDefinition example <primary_name>
        ```

        :param str resource_name: The name of the resource.
        :param LinkDefinitionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(LinkDefinitionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 associated_description: Optional[pulumi.Input[builtins.str]] = None,
                 associated_name: Optional[pulumi.Input[builtins.str]] = None,
                 associated_title: Optional[pulumi.Input[builtins.str]] = None,
                 primary_description: Optional[pulumi.Input[builtins.str]] = None,
                 primary_name: Optional[pulumi.Input[builtins.str]] = None,
                 primary_title: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = LinkDefinitionArgs.__new__(LinkDefinitionArgs)

            if associated_description is None and not opts.urn:
                raise TypeError("Missing required property 'associated_description'")
            __props__.__dict__["associated_description"] = associated_description
            if associated_name is None and not opts.urn:
                raise TypeError("Missing required property 'associated_name'")
            __props__.__dict__["associated_name"] = associated_name
            if associated_title is None and not opts.urn:
                raise TypeError("Missing required property 'associated_title'")
            __props__.__dict__["associated_title"] = associated_title
            if primary_description is None and not opts.urn:
                raise TypeError("Missing required property 'primary_description'")
            __props__.__dict__["primary_description"] = primary_description
            if primary_name is None and not opts.urn:
                raise TypeError("Missing required property 'primary_name'")
            __props__.__dict__["primary_name"] = primary_name
            if primary_title is None and not opts.urn:
                raise TypeError("Missing required property 'primary_title'")
            __props__.__dict__["primary_title"] = primary_title
        super(LinkDefinition, __self__).__init__(
            'okta:index/linkDefinition:LinkDefinition',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            associated_description: Optional[pulumi.Input[builtins.str]] = None,
            associated_name: Optional[pulumi.Input[builtins.str]] = None,
            associated_title: Optional[pulumi.Input[builtins.str]] = None,
            primary_description: Optional[pulumi.Input[builtins.str]] = None,
            primary_name: Optional[pulumi.Input[builtins.str]] = None,
            primary_title: Optional[pulumi.Input[builtins.str]] = None) -> 'LinkDefinition':
        """
        Get an existing LinkDefinition resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] associated_description: Description of the associated relationship.
        :param pulumi.Input[builtins.str] associated_name: API name of the associated link.
        :param pulumi.Input[builtins.str] associated_title: Display name of the associated link.
        :param pulumi.Input[builtins.str] primary_description: Description of the primary relationship.
        :param pulumi.Input[builtins.str] primary_name: API name of the primary link.
        :param pulumi.Input[builtins.str] primary_title: Display name of the primary link.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _LinkDefinitionState.__new__(_LinkDefinitionState)

        __props__.__dict__["associated_description"] = associated_description
        __props__.__dict__["associated_name"] = associated_name
        __props__.__dict__["associated_title"] = associated_title
        __props__.__dict__["primary_description"] = primary_description
        __props__.__dict__["primary_name"] = primary_name
        __props__.__dict__["primary_title"] = primary_title
        return LinkDefinition(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="associatedDescription")
    def associated_description(self) -> pulumi.Output[builtins.str]:
        """
        Description of the associated relationship.
        """
        return pulumi.get(self, "associated_description")

    @property
    @pulumi.getter(name="associatedName")
    def associated_name(self) -> pulumi.Output[builtins.str]:
        """
        API name of the associated link.
        """
        return pulumi.get(self, "associated_name")

    @property
    @pulumi.getter(name="associatedTitle")
    def associated_title(self) -> pulumi.Output[builtins.str]:
        """
        Display name of the associated link.
        """
        return pulumi.get(self, "associated_title")

    @property
    @pulumi.getter(name="primaryDescription")
    def primary_description(self) -> pulumi.Output[builtins.str]:
        """
        Description of the primary relationship.
        """
        return pulumi.get(self, "primary_description")

    @property
    @pulumi.getter(name="primaryName")
    def primary_name(self) -> pulumi.Output[builtins.str]:
        """
        API name of the primary link.
        """
        return pulumi.get(self, "primary_name")

    @property
    @pulumi.getter(name="primaryTitle")
    def primary_title(self) -> pulumi.Output[builtins.str]:
        """
        Display name of the primary link.
        """
        return pulumi.get(self, "primary_title")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['LogStreamArgs', 'LogStream']

@pulumi.input_type
class LogStreamArgs:
    def __init__(__self__, *,
                 type: pulumi.Input[builtins.str],
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 settings: Optional[pulumi.Input['LogStreamSettingsArgs']] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a LogStream resource.
        :param pulumi.Input[builtins.str] type: Streaming provider used - 'aws*eventbridge' or 'splunk*cloud_logstreaming'
        :param pulumi.Input[builtins.str] name: Unique name for the Log Stream object
        :param pulumi.Input[builtins.str] status: Stream status
        """
        pulumi.set(__self__, "type", type)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if settings is not None:
            pulumi.set(__self__, "settings", settings)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[builtins.str]:
        """
        Streaming provider used - 'aws*eventbridge' or 'splunk*cloud_logstreaming'
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Unique name for the Log Stream object
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def settings(self) -> Optional[pulumi.Input['LogStreamSettingsArgs']]:
        return pulumi.get(self, "settings")

    @settings.setter
    def settings(self, value: Optional[pulumi.Input['LogStreamSettingsArgs']]):
        pulumi.set(self, "settings", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Stream status
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.input_type
class _LogStreamState:
    def __init__(__self__, *,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 settings: Optional[pulumi.Input['LogStreamSettingsArgs']] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering LogStream resources.
        :param pulumi.Input[builtins.str] name: Unique name for the Log Stream object
        :param pulumi.Input[builtins.str] status: Stream status
        :param pulumi.Input[builtins.str] type: Streaming provider used - 'aws*eventbridge' or 'splunk*cloud_logstreaming'
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if settings is not None:
            pulumi.set(__self__, "settings", settings)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Unique name for the Log Stream object
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def settings(self) -> Optional[pulumi.Input['LogStreamSettingsArgs']]:
        return pulumi.get(self, "settings")

    @settings.setter
    def settings(self, value: Optional[pulumi.Input['LogStreamSettingsArgs']]):
        pulumi.set(self, "settings", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Stream status
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Streaming provider used - 'aws*eventbridge' or 'splunk*cloud_logstreaming'
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.type_token("okta:index/logStream:LogStream")
class LogStream(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 settings: Optional[pulumi.Input[Union['LogStreamSettingsArgs', 'LogStreamSettingsArgsDict']]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Manages log streams

        ## Import

        ```sh
        $ pulumi import okta:index/logStream:LogStream example <stream_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] name: Unique name for the Log Stream object
        :param pulumi.Input[builtins.str] status: Stream status
        :param pulumi.Input[builtins.str] type: Streaming provider used - 'aws*eventbridge' or 'splunk*cloud_logstreaming'
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: LogStreamArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages log streams

        ## Import

        ```sh
        $ pulumi import okta:index/logStream:LogStream example <stream_id>
        ```

        :param str resource_name: The name of the resource.
        :param LogStreamArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(LogStreamArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 settings: Optional[pulumi.Input[Union['LogStreamSettingsArgs', 'LogStreamSettingsArgsDict']]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = LogStreamArgs.__new__(LogStreamArgs)

            __props__.__dict__["name"] = name
            __props__.__dict__["settings"] = settings
            __props__.__dict__["status"] = status
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
        super(LogStream, __self__).__init__(
            'okta:index/logStream:LogStream',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            settings: Optional[pulumi.Input[Union['LogStreamSettingsArgs', 'LogStreamSettingsArgsDict']]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            type: Optional[pulumi.Input[builtins.str]] = None) -> 'LogStream':
        """
        Get an existing LogStream resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] name: Unique name for the Log Stream object
        :param pulumi.Input[builtins.str] status: Stream status
        :param pulumi.Input[builtins.str] type: Streaming provider used - 'aws*eventbridge' or 'splunk*cloud_logstreaming'
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _LogStreamState.__new__(_LogStreamState)

        __props__.__dict__["name"] = name
        __props__.__dict__["settings"] = settings
        __props__.__dict__["status"] = status
        __props__.__dict__["type"] = type
        return LogStream(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        Unique name for the Log Stream object
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def settings(self) -> pulumi.Output[Optional['outputs.LogStreamSettings']]:
        return pulumi.get(self, "settings")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Stream status
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[builtins.str]:
        """
        Streaming provider used - 'aws*eventbridge' or 'splunk*cloud_logstreaming'
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetTrustedOriginsResult',
    'AwaitableGetTrustedOriginsResult',
    'get_trusted_origins',
    'get_trusted_origins_output',
]

@pulumi.output_type
class GetTrustedOriginsResult:
    """
    A collection of values returned by getTrustedOrigins.
    """
    def __init__(__self__, filter=None, id=None, trusted_origins=None):
        if filter and not isinstance(filter, str):
            raise TypeError("Expected argument 'filter' to be a str")
        pulumi.set(__self__, "filter", filter)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if trusted_origins and not isinstance(trusted_origins, list):
            raise TypeError("Expected argument 'trusted_origins' to be a list")
        pulumi.set(__self__, "trusted_origins", trusted_origins)

    @property
    @pulumi.getter
    def filter(self) -> Optional[builtins.str]:
        """
        Filter criteria. Filter value will be URL-encoded by the provider
        """
        return pulumi.get(self, "filter")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="trustedOrigins")
    def trusted_origins(self) -> Sequence['outputs.GetTrustedOriginsTrustedOriginResult']:
        return pulumi.get(self, "trusted_origins")


class AwaitableGetTrustedOriginsResult(GetTrustedOriginsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTrustedOriginsResult(
            filter=self.filter,
            id=self.id,
            trusted_origins=self.trusted_origins)


def get_trusted_origins(filter: Optional[builtins.str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTrustedOriginsResult:
    """
    Get List of Trusted Origins using filters.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    all = okta.get_trusted_origins()
    ```


    :param builtins.str filter: Filter criteria. Filter value will be URL-encoded by the provider
    """
    __args__ = dict()
    __args__['filter'] = filter
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getTrustedOrigins:getTrustedOrigins', __args__, opts=opts, typ=GetTrustedOriginsResult).value

    return AwaitableGetTrustedOriginsResult(
        filter=pulumi.get(__ret__, 'filter'),
        id=pulumi.get(__ret__, 'id'),
        trusted_origins=pulumi.get(__ret__, 'trusted_origins'))
def get_trusted_origins_output(filter: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                               opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetTrustedOriginsResult]:
    """
    Get List of Trusted Origins using filters.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    all = okta.get_trusted_origins()
    ```


    :param builtins.str filter: Filter criteria. Filter value will be URL-encoded by the provider
    """
    __args__ = dict()
    __args__['filter'] = filter
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getTrustedOrigins:getTrustedOrigins', __args__, opts=opts, typ=GetTrustedOriginsResult)
    return __ret__.apply(lambda __response__: GetTrustedOriginsResult(
        filter=pulumi.get(__response__, 'filter'),
        id=pulumi.get(__response__, 'id'),
        trusted_origins=pulumi.get(__response__, 'trusted_origins')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetAuthServerClaimsResult',
    'AwaitableGetAuthServerClaimsResult',
    'get_auth_server_claims',
    'get_auth_server_claims_output',
]

@pulumi.output_type
class GetAuthServerClaimsResult:
    """
    A collection of values returned by getAuthServerClaims.
    """
    def __init__(__self__, auth_server_id=None, claims=None, id=None):
        if auth_server_id and not isinstance(auth_server_id, str):
            raise TypeError("Expected argument 'auth_server_id' to be a str")
        pulumi.set(__self__, "auth_server_id", auth_server_id)
        if claims and not isinstance(claims, list):
            raise TypeError("Expected argument 'claims' to be a list")
        pulumi.set(__self__, "claims", claims)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter(name="authServerId")
    def auth_server_id(self) -> builtins.str:
        """
        Auth server ID
        """
        return pulumi.get(self, "auth_server_id")

    @property
    @pulumi.getter
    def claims(self) -> Sequence['outputs.GetAuthServerClaimsClaimResult']:
        """
        Collection of authorization server claims retrieved from Okta with the following properties.
        """
        return pulumi.get(self, "claims")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")


class AwaitableGetAuthServerClaimsResult(GetAuthServerClaimsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAuthServerClaimsResult(
            auth_server_id=self.auth_server_id,
            claims=self.claims,
            id=self.id)


def get_auth_server_claims(auth_server_id: Optional[builtins.str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAuthServerClaimsResult:
    """
    Get a list of authorization server claims from Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.get_auth_server_claims(auth_server_id="default")
    ```


    :param builtins.str auth_server_id: Auth server ID
    """
    __args__ = dict()
    __args__['authServerId'] = auth_server_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getAuthServerClaims:getAuthServerClaims', __args__, opts=opts, typ=GetAuthServerClaimsResult).value

    return AwaitableGetAuthServerClaimsResult(
        auth_server_id=pulumi.get(__ret__, 'auth_server_id'),
        claims=pulumi.get(__ret__, 'claims'),
        id=pulumi.get(__ret__, 'id'))
def get_auth_server_claims_output(auth_server_id: Optional[pulumi.Input[builtins.str]] = None,
                                  opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAuthServerClaimsResult]:
    """
    Get a list of authorization server claims from Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.get_auth_server_claims(auth_server_id="default")
    ```


    :param builtins.str auth_server_id: Auth server ID
    """
    __args__ = dict()
    __args__['authServerId'] = auth_server_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getAuthServerClaims:getAuthServerClaims', __args__, opts=opts, typ=GetAuthServerClaimsResult)
    return __ret__.apply(lambda __response__: GetAuthServerClaimsResult(
        auth_server_id=pulumi.get(__response__, 'auth_server_id'),
        claims=pulumi.get(__response__, 'claims'),
        id=pulumi.get(__response__, 'id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['FactorArgs', 'Factor']

@pulumi.input_type
class FactorArgs:
    def __init__(__self__, *,
                 provider_id: pulumi.Input[builtins.str],
                 active: Optional[pulumi.Input[builtins.bool]] = None):
        """
        The set of arguments for constructing a Factor resource.
        :param pulumi.Input[builtins.str] provider_id: The MFA provider name. Allowed values are `duo`, `fido_u2f`, `fido_webauthn`, `google_otp`, `okta_call`, `okta_otp`, `okta_password`, `okta_push`, `okta_question`, `okta_sms`, `okta_email`, `rsa_token`, `symantec_vip`, `yubikey_token`, or `hotp`.
        :param pulumi.Input[builtins.bool] active: Whether to activate the provider, by default, it is set to `true`.
        """
        pulumi.set(__self__, "provider_id", provider_id)
        if active is not None:
            pulumi.set(__self__, "active", active)

    @property
    @pulumi.getter(name="providerId")
    def provider_id(self) -> pulumi.Input[builtins.str]:
        """
        The MFA provider name. Allowed values are `duo`, `fido_u2f`, `fido_webauthn`, `google_otp`, `okta_call`, `okta_otp`, `okta_password`, `okta_push`, `okta_question`, `okta_sms`, `okta_email`, `rsa_token`, `symantec_vip`, `yubikey_token`, or `hotp`.
        """
        return pulumi.get(self, "provider_id")

    @provider_id.setter
    def provider_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "provider_id", value)

    @property
    @pulumi.getter
    def active(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to activate the provider, by default, it is set to `true`.
        """
        return pulumi.get(self, "active")

    @active.setter
    def active(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "active", value)


@pulumi.input_type
class _FactorState:
    def __init__(__self__, *,
                 active: Optional[pulumi.Input[builtins.bool]] = None,
                 provider_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Factor resources.
        :param pulumi.Input[builtins.bool] active: Whether to activate the provider, by default, it is set to `true`.
        :param pulumi.Input[builtins.str] provider_id: The MFA provider name. Allowed values are `duo`, `fido_u2f`, `fido_webauthn`, `google_otp`, `okta_call`, `okta_otp`, `okta_password`, `okta_push`, `okta_question`, `okta_sms`, `okta_email`, `rsa_token`, `symantec_vip`, `yubikey_token`, or `hotp`.
        """
        if active is not None:
            pulumi.set(__self__, "active", active)
        if provider_id is not None:
            pulumi.set(__self__, "provider_id", provider_id)

    @property
    @pulumi.getter
    def active(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to activate the provider, by default, it is set to `true`.
        """
        return pulumi.get(self, "active")

    @active.setter
    def active(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "active", value)

    @property
    @pulumi.getter(name="providerId")
    def provider_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The MFA provider name. Allowed values are `duo`, `fido_u2f`, `fido_webauthn`, `google_otp`, `okta_call`, `okta_otp`, `okta_password`, `okta_push`, `okta_question`, `okta_sms`, `okta_email`, `rsa_token`, `symantec_vip`, `yubikey_token`, or `hotp`.
        """
        return pulumi.get(self, "provider_id")

    @provider_id.setter
    def provider_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "provider_id", value)


@pulumi.type_token("okta:factor/factor:Factor")
class Factor(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 active: Optional[pulumi.Input[builtins.bool]] = None,
                 provider_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Allows you to manage the activation of Okta MFA methods. This resource allows you to manage Okta MFA methods.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.factor.Factor("example", provider_id="google_otp")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] active: Whether to activate the provider, by default, it is set to `true`.
        :param pulumi.Input[builtins.str] provider_id: The MFA provider name. Allowed values are `duo`, `fido_u2f`, `fido_webauthn`, `google_otp`, `okta_call`, `okta_otp`, `okta_password`, `okta_push`, `okta_question`, `okta_sms`, `okta_email`, `rsa_token`, `symantec_vip`, `yubikey_token`, or `hotp`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: FactorArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Allows you to manage the activation of Okta MFA methods. This resource allows you to manage Okta MFA methods.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.factor.Factor("example", provider_id="google_otp")
        ```

        :param str resource_name: The name of the resource.
        :param FactorArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(FactorArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 active: Optional[pulumi.Input[builtins.bool]] = None,
                 provider_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = FactorArgs.__new__(FactorArgs)

            __props__.__dict__["active"] = active
            if provider_id is None and not opts.urn:
                raise TypeError("Missing required property 'provider_id'")
            __props__.__dict__["provider_id"] = provider_id
        super(Factor, __self__).__init__(
            'okta:factor/factor:Factor',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            active: Optional[pulumi.Input[builtins.bool]] = None,
            provider_id: Optional[pulumi.Input[builtins.str]] = None) -> 'Factor':
        """
        Get an existing Factor resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] active: Whether to activate the provider, by default, it is set to `true`.
        :param pulumi.Input[builtins.str] provider_id: The MFA provider name. Allowed values are `duo`, `fido_u2f`, `fido_webauthn`, `google_otp`, `okta_call`, `okta_otp`, `okta_password`, `okta_push`, `okta_question`, `okta_sms`, `okta_email`, `rsa_token`, `symantec_vip`, `yubikey_token`, or `hotp`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _FactorState.__new__(_FactorState)

        __props__.__dict__["active"] = active
        __props__.__dict__["provider_id"] = provider_id
        return Factor(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def active(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Whether to activate the provider, by default, it is set to `true`.
        """
        return pulumi.get(self, "active")

    @property
    @pulumi.getter(name="providerId")
    def provider_id(self) -> pulumi.Output[builtins.str]:
        """
        The MFA provider name. Allowed values are `duo`, `fido_u2f`, `fido_webauthn`, `google_otp`, `okta_call`, `okta_otp`, `okta_password`, `okta_push`, `okta_question`, `okta_sms`, `okta_email`, `rsa_token`, `symantec_vip`, `yubikey_token`, or `hotp`.
        """
        return pulumi.get(self, "provider_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetAppGroupAssignmentsResult',
    'AwaitableGetAppGroupAssignmentsResult',
    'get_app_group_assignments',
    'get_app_group_assignments_output',
]

@pulumi.output_type
class GetAppGroupAssignmentsResult:
    """
    A collection of values returned by getAppGroupAssignments.
    """
    def __init__(__self__, groups=None, id=None):
        if groups and not isinstance(groups, list):
            raise TypeError("Expected argument 'groups' to be a list")
        pulumi.set(__self__, "groups", groups)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter
    def groups(self) -> Sequence[builtins.str]:
        """
        List of groups IDs assigned to the app
        """
        return pulumi.get(self, "groups")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        ID of the Okta App being queried for groups
        """
        return pulumi.get(self, "id")


class AwaitableGetAppGroupAssignmentsResult(GetAppGroupAssignmentsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAppGroupAssignmentsResult(
            groups=self.groups,
            id=self.id)


def get_app_group_assignments(id: Optional[builtins.str] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAppGroupAssignmentsResult:
    """
    Get a set of groups assigned to an Okta application.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.get_app_group_assignments(id=test_okta_app_oauth["id"])
    ```


    :param builtins.str id: ID of the Okta App being queried for groups
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getAppGroupAssignments:getAppGroupAssignments', __args__, opts=opts, typ=GetAppGroupAssignmentsResult).value

    return AwaitableGetAppGroupAssignmentsResult(
        groups=pulumi.get(__ret__, 'groups'),
        id=pulumi.get(__ret__, 'id'))
def get_app_group_assignments_output(id: Optional[pulumi.Input[builtins.str]] = None,
                                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAppGroupAssignmentsResult]:
    """
    Get a set of groups assigned to an Okta application.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.get_app_group_assignments(id=test_okta_app_oauth["id"])
    ```


    :param builtins.str id: ID of the Okta App being queried for groups
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getAppGroupAssignments:getAppGroupAssignments', __args__, opts=opts, typ=GetAppGroupAssignmentsResult)
    return __ret__.apply(lambda __response__: GetAppGroupAssignmentsResult(
        groups=pulumi.get(__response__, 'groups'),
        id=pulumi.get(__response__, 'id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['SamlKeyArgs', 'SamlKey']

@pulumi.input_type
class SamlKeyArgs:
    def __init__(__self__, *,
                 x5cs: pulumi.Input[Sequence[pulumi.Input[builtins.str]]]):
        """
        The set of arguments for constructing a SamlKey resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] x5cs: base64-encoded X.509 certificate chain with DER encoding
        """
        pulumi.set(__self__, "x5cs", x5cs)

    @property
    @pulumi.getter
    def x5cs(self) -> pulumi.Input[Sequence[pulumi.Input[builtins.str]]]:
        """
        base64-encoded X.509 certificate chain with DER encoding
        """
        return pulumi.get(self, "x5cs")

    @x5cs.setter
    def x5cs(self, value: pulumi.Input[Sequence[pulumi.Input[builtins.str]]]):
        pulumi.set(self, "x5cs", value)


@pulumi.input_type
class _SamlKeyState:
    def __init__(__self__, *,
                 created: Optional[pulumi.Input[builtins.str]] = None,
                 expires_at: Optional[pulumi.Input[builtins.str]] = None,
                 kid: Optional[pulumi.Input[builtins.str]] = None,
                 kty: Optional[pulumi.Input[builtins.str]] = None,
                 use: Optional[pulumi.Input[builtins.str]] = None,
                 x5cs: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 x5t_s256: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering SamlKey resources.
        :param pulumi.Input[builtins.str] created: Date created.
        :param pulumi.Input[builtins.str] expires_at: Date the cert expires.
        :param pulumi.Input[builtins.str] kid: Key ID.
        :param pulumi.Input[builtins.str] kty: Identifies the cryptographic algorithm family used with the key.
        :param pulumi.Input[builtins.str] use: Intended use of the public key.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] x5cs: base64-encoded X.509 certificate chain with DER encoding
        :param pulumi.Input[builtins.str] x5t_s256: base64url-encoded SHA-256 thumbprint of the DER encoding of an X.509 certificate.
        """
        if created is not None:
            pulumi.set(__self__, "created", created)
        if expires_at is not None:
            pulumi.set(__self__, "expires_at", expires_at)
        if kid is not None:
            pulumi.set(__self__, "kid", kid)
        if kty is not None:
            pulumi.set(__self__, "kty", kty)
        if use is not None:
            pulumi.set(__self__, "use", use)
        if x5cs is not None:
            pulumi.set(__self__, "x5cs", x5cs)
        if x5t_s256 is not None:
            pulumi.set(__self__, "x5t_s256", x5t_s256)

    @property
    @pulumi.getter
    def created(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Date created.
        """
        return pulumi.get(self, "created")

    @created.setter
    def created(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created", value)

    @property
    @pulumi.getter(name="expiresAt")
    def expires_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Date the cert expires.
        """
        return pulumi.get(self, "expires_at")

    @expires_at.setter
    def expires_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "expires_at", value)

    @property
    @pulumi.getter
    def kid(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Key ID.
        """
        return pulumi.get(self, "kid")

    @kid.setter
    def kid(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kid", value)

    @property
    @pulumi.getter
    def kty(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Identifies the cryptographic algorithm family used with the key.
        """
        return pulumi.get(self, "kty")

    @kty.setter
    def kty(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kty", value)

    @property
    @pulumi.getter
    def use(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Intended use of the public key.
        """
        return pulumi.get(self, "use")

    @use.setter
    def use(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "use", value)

    @property
    @pulumi.getter
    def x5cs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        base64-encoded X.509 certificate chain with DER encoding
        """
        return pulumi.get(self, "x5cs")

    @x5cs.setter
    def x5cs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "x5cs", value)

    @property
    @pulumi.getter(name="x5tS256")
    def x5t_s256(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        base64url-encoded SHA-256 thumbprint of the DER encoding of an X.509 certificate.
        """
        return pulumi.get(self, "x5t_s256")

    @x5t_s256.setter
    def x5t_s256(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "x5t_s256", value)


@pulumi.type_token("okta:idp/samlKey:SamlKey")
class SamlKey(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 x5cs: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example1 = okta.idp.SamlKey("example_1", x5cs=[example["certificate"]])
        example2 = okta.idp.SamlKey("example_2", x5cs=[\"\"\"MIIDnjCCAoagAwIBAgIGAVG3MN+PMA0GCSqGSIb3DQEBBQUAMIGPMQswCQYDVQQGEwJVUzETMBEGA1UECAwKQ2FsaWZvcm5p
        YTEWMBQGA1UEBwwNU2FuIEZyYW5jaXNjbzENMAsGA1UECgwET2t0YTEUMBIGA1UECwwLU1NPUHJvdmlkZXIxEDAOBgNVBAMM
        B2V4YW1wbGUxHDAaBgkqhkiG9w0BCQEWDWluZm9Ab2t0YS5jb20wHhcNMTUxMjE4MjIyMjMyWhcNMjUxMjE4MjIyMzMyWjCB
        jzELMAkGA1UEBhMCVVMxEzARBgNVBAgMCkNhbGlmb3JuaWExFjAUBgNVBAcMDVNhbiBGcmFuY2lzY28xDTALBgNVBAoMBE9r
        dGExFDASBgNVBAsMC1NTT1Byb3ZpZGVyMRAwDgYDVQQDDAdleGFtcGxlMRwwGgYJKoZIhvcNAQkBFg1pbmZvQG9rdGEuY29t
        MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAtcnyvuVCrsFEKCwHDenS3Ocjed8eWDv3zLtD2K/iZfE8BMj2wpTf
        n6Ry8zCYey3mWlKdxIybnV9amrujGRnE0ab6Q16v9D6RlFQLOG6dwqoRKuZy33Uyg8PGdEudZjGbWuKCqqXEp+UKALJHV+k4
        wWeVH8g5d1n3KyR2TVajVJpCrPhLFmq1Il4G/IUnPe4MvjXqB6CpKkog1+ThWsItPRJPAM+RweFHXq7KfChXsYE7Mmfuly8s
        DQlvBmQyxZnFHVuiPfCvGHJjpvHy11YlHdOjfgqHRvZbmo30+y0X/oY/yV4YEJ00LL6eJWU4wi7ViY3HP6/VCdRjHoRdr5L/
        DwIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQCzzhOFkvyYLNFj2WDcq1YqD4sBy1iCia9QpRH3rjQvMKDwQDYWbi6EdOX0TQ/I
        YR7UWGj+2pXd6v0t33lYtoKocp/4lUvT3tfBnWZ5KnObi+J2uY2teUqoYkASN7F+GRPVOuMVoVgm05ss8tuMb2dLc9vsx93s
        Dt+XlMTv/2qi5VPwaDtqduKkzwW9lUfn4xIMkTiVvCpe0X2HneD2Bpuao3/U8Rk0uiPfq6TooWaoW3kjsmErhEAs9bA7xuqo
        1KKY9CdHcFhkSsMhoeaZylZHtzbnoipUlQKSLMdJQiiYZQ0bYL83/Ta9fulr1EERICMFt3GUmtYaZZKHpWSfdJp9\"\"\"])
        ```

        ## Import

        ```sh
        $ pulumi import okta:idp/samlKey:SamlKey example <key_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] x5cs: base64-encoded X.509 certificate chain with DER encoding
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SamlKeyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example1 = okta.idp.SamlKey("example_1", x5cs=[example["certificate"]])
        example2 = okta.idp.SamlKey("example_2", x5cs=[\"\"\"MIIDnjCCAoagAwIBAgIGAVG3MN+PMA0GCSqGSIb3DQEBBQUAMIGPMQswCQYDVQQGEwJVUzETMBEGA1UECAwKQ2FsaWZvcm5p
        YTEWMBQGA1UEBwwNU2FuIEZyYW5jaXNjbzENMAsGA1UECgwET2t0YTEUMBIGA1UECwwLU1NPUHJvdmlkZXIxEDAOBgNVBAMM
        B2V4YW1wbGUxHDAaBgkqhkiG9w0BCQEWDWluZm9Ab2t0YS5jb20wHhcNMTUxMjE4MjIyMjMyWhcNMjUxMjE4MjIyMzMyWjCB
        jzELMAkGA1UEBhMCVVMxEzARBgNVBAgMCkNhbGlmb3JuaWExFjAUBgNVBAcMDVNhbiBGcmFuY2lzY28xDTALBgNVBAoMBE9r
        dGExFDASBgNVBAsMC1NTT1Byb3ZpZGVyMRAwDgYDVQQDDAdleGFtcGxlMRwwGgYJKoZIhvcNAQkBFg1pbmZvQG9rdGEuY29t
        MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAtcnyvuVCrsFEKCwHDenS3Ocjed8eWDv3zLtD2K/iZfE8BMj2wpTf
        n6Ry8zCYey3mWlKdxIybnV9amrujGRnE0ab6Q16v9D6RlFQLOG6dwqoRKuZy33Uyg8PGdEudZjGbWuKCqqXEp+UKALJHV+k4
        wWeVH8g5d1n3KyR2TVajVJpCrPhLFmq1Il4G/IUnPe4MvjXqB6CpKkog1+ThWsItPRJPAM+RweFHXq7KfChXsYE7Mmfuly8s
        DQlvBmQyxZnFHVuiPfCvGHJjpvHy11YlHdOjfgqHRvZbmo30+y0X/oY/yV4YEJ00LL6eJWU4wi7ViY3HP6/VCdRjHoRdr5L/
        DwIDAQABMA0GCSqGSIb3DQEBBQUAA4IBAQCzzhOFkvyYLNFj2WDcq1YqD4sBy1iCia9QpRH3rjQvMKDwQDYWbi6EdOX0TQ/I
        YR7UWGj+2pXd6v0t33lYtoKocp/4lUvT3tfBnWZ5KnObi+J2uY2teUqoYkASN7F+GRPVOuMVoVgm05ss8tuMb2dLc9vsx93s
        Dt+XlMTv/2qi5VPwaDtqduKkzwW9lUfn4xIMkTiVvCpe0X2HneD2Bpuao3/U8Rk0uiPfq6TooWaoW3kjsmErhEAs9bA7xuqo
        1KKY9CdHcFhkSsMhoeaZylZHtzbnoipUlQKSLMdJQiiYZQ0bYL83/Ta9fulr1EERICMFt3GUmtYaZZKHpWSfdJp9\"\"\"])
        ```

        ## Import

        ```sh
        $ pulumi import okta:idp/samlKey:SamlKey example <key_id>
        ```

        :param str resource_name: The name of the resource.
        :param SamlKeyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SamlKeyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 x5cs: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SamlKeyArgs.__new__(SamlKeyArgs)

            if x5cs is None and not opts.urn:
                raise TypeError("Missing required property 'x5cs'")
            __props__.__dict__["x5cs"] = x5cs
            __props__.__dict__["created"] = None
            __props__.__dict__["expires_at"] = None
            __props__.__dict__["kid"] = None
            __props__.__dict__["kty"] = None
            __props__.__dict__["use"] = None
            __props__.__dict__["x5t_s256"] = None
        super(SamlKey, __self__).__init__(
            'okta:idp/samlKey:SamlKey',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created: Optional[pulumi.Input[builtins.str]] = None,
            expires_at: Optional[pulumi.Input[builtins.str]] = None,
            kid: Optional[pulumi.Input[builtins.str]] = None,
            kty: Optional[pulumi.Input[builtins.str]] = None,
            use: Optional[pulumi.Input[builtins.str]] = None,
            x5cs: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            x5t_s256: Optional[pulumi.Input[builtins.str]] = None) -> 'SamlKey':
        """
        Get an existing SamlKey resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] created: Date created.
        :param pulumi.Input[builtins.str] expires_at: Date the cert expires.
        :param pulumi.Input[builtins.str] kid: Key ID.
        :param pulumi.Input[builtins.str] kty: Identifies the cryptographic algorithm family used with the key.
        :param pulumi.Input[builtins.str] use: Intended use of the public key.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] x5cs: base64-encoded X.509 certificate chain with DER encoding
        :param pulumi.Input[builtins.str] x5t_s256: base64url-encoded SHA-256 thumbprint of the DER encoding of an X.509 certificate.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SamlKeyState.__new__(_SamlKeyState)

        __props__.__dict__["created"] = created
        __props__.__dict__["expires_at"] = expires_at
        __props__.__dict__["kid"] = kid
        __props__.__dict__["kty"] = kty
        __props__.__dict__["use"] = use
        __props__.__dict__["x5cs"] = x5cs
        __props__.__dict__["x5t_s256"] = x5t_s256
        return SamlKey(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def created(self) -> pulumi.Output[builtins.str]:
        """
        Date created.
        """
        return pulumi.get(self, "created")

    @property
    @pulumi.getter(name="expiresAt")
    def expires_at(self) -> pulumi.Output[builtins.str]:
        """
        Date the cert expires.
        """
        return pulumi.get(self, "expires_at")

    @property
    @pulumi.getter
    def kid(self) -> pulumi.Output[builtins.str]:
        """
        Key ID.
        """
        return pulumi.get(self, "kid")

    @property
    @pulumi.getter
    def kty(self) -> pulumi.Output[builtins.str]:
        """
        Identifies the cryptographic algorithm family used with the key.
        """
        return pulumi.get(self, "kty")

    @property
    @pulumi.getter
    def use(self) -> pulumi.Output[builtins.str]:
        """
        Intended use of the public key.
        """
        return pulumi.get(self, "use")

    @property
    @pulumi.getter
    def x5cs(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        base64-encoded X.509 certificate chain with DER encoding
        """
        return pulumi.get(self, "x5cs")

    @property
    @pulumi.getter(name="x5tS256")
    def x5t_s256(self) -> pulumi.Output[builtins.str]:
        """
        base64url-encoded SHA-256 thumbprint of the DER encoding of an X.509 certificate.
        """
        return pulumi.get(self, "x5t_s256")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetAppSignonPolicyResult',
    'AwaitableGetAppSignonPolicyResult',
    'get_app_signon_policy',
    'get_app_signon_policy_output',
]

@pulumi.output_type
class GetAppSignonPolicyResult:
    """
    A collection of values returned by getAppSignonPolicy.
    """
    def __init__(__self__, app_id=None, id=None, name=None):
        if app_id and not isinstance(app_id, str):
            raise TypeError("Expected argument 'app_id' to be a str")
        pulumi.set(__self__, "app_id", app_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="appId")
    def app_id(self) -> builtins.str:
        """
        App ID
        """
        return pulumi.get(self, "app_id")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        Policy name
        """
        return pulumi.get(self, "name")


class AwaitableGetAppSignonPolicyResult(GetAppSignonPolicyResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAppSignonPolicyResult(
            app_id=self.app_id,
            id=self.id,
            name=self.name)


def get_app_signon_policy(app_id: Optional[builtins.str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAppSignonPolicyResult:
    """
    Get a sign-on policy for the application.

    > **WARNING:** This feature is only available as a part of the
    Identity Engine. Contact support
    for further information.

    > Inside the product a sign-on policy is referenced as an _authentication
    policy_, in the public API the policy is of type
    [`ACCESS_POLICY`](https://developer.okta.com/docs/reference/api/policy/#policy-object).

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.get_app_signon_policy(app_id="app_id")
    ```


    :param builtins.str app_id: App ID
    """
    __args__ = dict()
    __args__['appId'] = app_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getAppSignonPolicy:getAppSignonPolicy', __args__, opts=opts, typ=GetAppSignonPolicyResult).value

    return AwaitableGetAppSignonPolicyResult(
        app_id=pulumi.get(__ret__, 'app_id'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'))
def get_app_signon_policy_output(app_id: Optional[pulumi.Input[builtins.str]] = None,
                                 opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAppSignonPolicyResult]:
    """
    Get a sign-on policy for the application.

    > **WARNING:** This feature is only available as a part of the
    Identity Engine. Contact support
    for further information.

    > Inside the product a sign-on policy is referenced as an _authentication
    policy_, in the public API the policy is of type
    [`ACCESS_POLICY`](https://developer.okta.com/docs/reference/api/policy/#policy-object).

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.get_app_signon_policy(app_id="app_id")
    ```


    :param builtins.str app_id: App ID
    """
    __args__ = dict()
    __args__['appId'] = app_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getAppSignonPolicy:getAppSignonPolicy', __args__, opts=opts, typ=GetAppSignonPolicyResult)
    return __ret__.apply(lambda __response__: GetAppSignonPolicyResult(
        app_id=pulumi.get(__response__, 'app_id'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['CaptchaArgs', 'Captcha']

@pulumi.input_type
class CaptchaArgs:
    def __init__(__self__, *,
                 secret_key: pulumi.Input[builtins.str],
                 site_key: pulumi.Input[builtins.str],
                 type: pulumi.Input[builtins.str],
                 name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Captcha resource.
        :param pulumi.Input[builtins.str] secret_key: Secret key issued from the CAPTCHA vendor to perform server-side validation for a CAPTCHA token
        :param pulumi.Input[builtins.str] site_key: Site key issued from the CAPTCHA vendor to render a CAPTCHA on a page
        :param pulumi.Input[builtins.str] type: Type of the captcha. Valid values: `HCAPTCHA`, `RECAPTCHA_V2`
        :param pulumi.Input[builtins.str] name: Name of the CAPTCHA
        """
        pulumi.set(__self__, "secret_key", secret_key)
        pulumi.set(__self__, "site_key", site_key)
        pulumi.set(__self__, "type", type)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="secretKey")
    def secret_key(self) -> pulumi.Input[builtins.str]:
        """
        Secret key issued from the CAPTCHA vendor to perform server-side validation for a CAPTCHA token
        """
        return pulumi.get(self, "secret_key")

    @secret_key.setter
    def secret_key(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "secret_key", value)

    @property
    @pulumi.getter(name="siteKey")
    def site_key(self) -> pulumi.Input[builtins.str]:
        """
        Site key issued from the CAPTCHA vendor to render a CAPTCHA on a page
        """
        return pulumi.get(self, "site_key")

    @site_key.setter
    def site_key(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "site_key", value)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[builtins.str]:
        """
        Type of the captcha. Valid values: `HCAPTCHA`, `RECAPTCHA_V2`
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Name of the CAPTCHA
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _CaptchaState:
    def __init__(__self__, *,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 secret_key: Optional[pulumi.Input[builtins.str]] = None,
                 site_key: Optional[pulumi.Input[builtins.str]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Captcha resources.
        :param pulumi.Input[builtins.str] name: Name of the CAPTCHA
        :param pulumi.Input[builtins.str] secret_key: Secret key issued from the CAPTCHA vendor to perform server-side validation for a CAPTCHA token
        :param pulumi.Input[builtins.str] site_key: Site key issued from the CAPTCHA vendor to render a CAPTCHA on a page
        :param pulumi.Input[builtins.str] type: Type of the captcha. Valid values: `HCAPTCHA`, `RECAPTCHA_V2`
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if secret_key is not None:
            pulumi.set(__self__, "secret_key", secret_key)
        if site_key is not None:
            pulumi.set(__self__, "site_key", site_key)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Name of the CAPTCHA
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="secretKey")
    def secret_key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Secret key issued from the CAPTCHA vendor to perform server-side validation for a CAPTCHA token
        """
        return pulumi.get(self, "secret_key")

    @secret_key.setter
    def secret_key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "secret_key", value)

    @property
    @pulumi.getter(name="siteKey")
    def site_key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Site key issued from the CAPTCHA vendor to render a CAPTCHA on a page
        """
        return pulumi.get(self, "site_key")

    @site_key.setter
    def site_key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "site_key", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Type of the captcha. Valid values: `HCAPTCHA`, `RECAPTCHA_V2`
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.type_token("okta:index/captcha:Captcha")
class Captcha(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 secret_key: Optional[pulumi.Input[builtins.str]] = None,
                 site_key: Optional[pulumi.Input[builtins.str]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Creates different types of captcha.
        		> **WARNING:** This feature is only available as a part of the Identity Engine. Contact support for further information.
        		This resource allows you to create and configure a CAPTCHA.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.Captcha("example",
            name="My CAPTCHA",
            type="HCAPTCHA",
            site_key="some_key",
            secret_key="some_secret_key")
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/captcha:Captcha example <captcha_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] name: Name of the CAPTCHA
        :param pulumi.Input[builtins.str] secret_key: Secret key issued from the CAPTCHA vendor to perform server-side validation for a CAPTCHA token
        :param pulumi.Input[builtins.str] site_key: Site key issued from the CAPTCHA vendor to render a CAPTCHA on a page
        :param pulumi.Input[builtins.str] type: Type of the captcha. Valid values: `HCAPTCHA`, `RECAPTCHA_V2`
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: CaptchaArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates different types of captcha.
        		> **WARNING:** This feature is only available as a part of the Identity Engine. Contact support for further information.
        		This resource allows you to create and configure a CAPTCHA.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.Captcha("example",
            name="My CAPTCHA",
            type="HCAPTCHA",
            site_key="some_key",
            secret_key="some_secret_key")
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/captcha:Captcha example <captcha_id>
        ```

        :param str resource_name: The name of the resource.
        :param CaptchaArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CaptchaArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 secret_key: Optional[pulumi.Input[builtins.str]] = None,
                 site_key: Optional[pulumi.Input[builtins.str]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CaptchaArgs.__new__(CaptchaArgs)

            __props__.__dict__["name"] = name
            if secret_key is None and not opts.urn:
                raise TypeError("Missing required property 'secret_key'")
            __props__.__dict__["secret_key"] = None if secret_key is None else pulumi.Output.secret(secret_key)
            if site_key is None and not opts.urn:
                raise TypeError("Missing required property 'site_key'")
            __props__.__dict__["site_key"] = site_key
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["secretKey"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(Captcha, __self__).__init__(
            'okta:index/captcha:Captcha',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            secret_key: Optional[pulumi.Input[builtins.str]] = None,
            site_key: Optional[pulumi.Input[builtins.str]] = None,
            type: Optional[pulumi.Input[builtins.str]] = None) -> 'Captcha':
        """
        Get an existing Captcha resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] name: Name of the CAPTCHA
        :param pulumi.Input[builtins.str] secret_key: Secret key issued from the CAPTCHA vendor to perform server-side validation for a CAPTCHA token
        :param pulumi.Input[builtins.str] site_key: Site key issued from the CAPTCHA vendor to render a CAPTCHA on a page
        :param pulumi.Input[builtins.str] type: Type of the captcha. Valid values: `HCAPTCHA`, `RECAPTCHA_V2`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _CaptchaState.__new__(_CaptchaState)

        __props__.__dict__["name"] = name
        __props__.__dict__["secret_key"] = secret_key
        __props__.__dict__["site_key"] = site_key
        __props__.__dict__["type"] = type
        return Captcha(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        Name of the CAPTCHA
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="secretKey")
    def secret_key(self) -> pulumi.Output[builtins.str]:
        """
        Secret key issued from the CAPTCHA vendor to perform server-side validation for a CAPTCHA token
        """
        return pulumi.get(self, "secret_key")

    @property
    @pulumi.getter(name="siteKey")
    def site_key(self) -> pulumi.Output[builtins.str]:
        """
        Site key issued from the CAPTCHA vendor to render a CAPTCHA on a page
        """
        return pulumi.get(self, "site_key")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[builtins.str]:
        """
        Type of the captcha. Valid values: `HCAPTCHA`, `RECAPTCHA_V2`
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['TemplateSmsArgs', 'TemplateSms']

@pulumi.input_type
class TemplateSmsArgs:
    def __init__(__self__, *,
                 template: pulumi.Input[builtins.str],
                 type: pulumi.Input[builtins.str],
                 translations: Optional[pulumi.Input[Sequence[pulumi.Input['TemplateSmsTranslationArgs']]]] = None):
        """
        The set of arguments for constructing a TemplateSms resource.
        :param pulumi.Input[builtins.str] template: SMS default template
        :param pulumi.Input[builtins.str] type: SMS template type
        :param pulumi.Input[Sequence[pulumi.Input['TemplateSmsTranslationArgs']]] translations: Set of translations for a particular template.
        """
        pulumi.set(__self__, "template", template)
        pulumi.set(__self__, "type", type)
        if translations is not None:
            pulumi.set(__self__, "translations", translations)

    @property
    @pulumi.getter
    def template(self) -> pulumi.Input[builtins.str]:
        """
        SMS default template
        """
        return pulumi.get(self, "template")

    @template.setter
    def template(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "template", value)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[builtins.str]:
        """
        SMS template type
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def translations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['TemplateSmsTranslationArgs']]]]:
        """
        Set of translations for a particular template.
        """
        return pulumi.get(self, "translations")

    @translations.setter
    def translations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['TemplateSmsTranslationArgs']]]]):
        pulumi.set(self, "translations", value)


@pulumi.input_type
class _TemplateSmsState:
    def __init__(__self__, *,
                 template: Optional[pulumi.Input[builtins.str]] = None,
                 translations: Optional[pulumi.Input[Sequence[pulumi.Input['TemplateSmsTranslationArgs']]]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering TemplateSms resources.
        :param pulumi.Input[builtins.str] template: SMS default template
        :param pulumi.Input[Sequence[pulumi.Input['TemplateSmsTranslationArgs']]] translations: Set of translations for a particular template.
        :param pulumi.Input[builtins.str] type: SMS template type
        """
        if template is not None:
            pulumi.set(__self__, "template", template)
        if translations is not None:
            pulumi.set(__self__, "translations", translations)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def template(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        SMS default template
        """
        return pulumi.get(self, "template")

    @template.setter
    def template(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "template", value)

    @property
    @pulumi.getter
    def translations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['TemplateSmsTranslationArgs']]]]:
        """
        Set of translations for a particular template.
        """
        return pulumi.get(self, "translations")

    @translations.setter
    def translations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['TemplateSmsTranslationArgs']]]]):
        pulumi.set(self, "translations", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        SMS template type
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.type_token("okta:index/templateSms:TemplateSms")
class TemplateSms(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 template: Optional[pulumi.Input[builtins.str]] = None,
                 translations: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TemplateSmsTranslationArgs', 'TemplateSmsTranslationArgsDict']]]]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Creates an Okta SMS Template. This resource allows you to create and configure an Okta SMS Template.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.TemplateSms("example",
            type="SMS_VERIFY_CODE",
            template="Your ${org.name} code is: ${code}",
            translations=[
                {
                    "language": "en",
                    "template": "Your ${org.name} code is: ${code}",
                },
                {
                    "language": "es",
                    "template": "Tu código de ${org.name} es: ${code}.",
                },
            ])
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/templateSms:TemplateSms example <template_type>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] template: SMS default template
        :param pulumi.Input[Sequence[pulumi.Input[Union['TemplateSmsTranslationArgs', 'TemplateSmsTranslationArgsDict']]]] translations: Set of translations for a particular template.
        :param pulumi.Input[builtins.str] type: SMS template type
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TemplateSmsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates an Okta SMS Template. This resource allows you to create and configure an Okta SMS Template.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.TemplateSms("example",
            type="SMS_VERIFY_CODE",
            template="Your ${org.name} code is: ${code}",
            translations=[
                {
                    "language": "en",
                    "template": "Your ${org.name} code is: ${code}",
                },
                {
                    "language": "es",
                    "template": "Tu código de ${org.name} es: ${code}.",
                },
            ])
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/templateSms:TemplateSms example <template_type>
        ```

        :param str resource_name: The name of the resource.
        :param TemplateSmsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TemplateSmsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 template: Optional[pulumi.Input[builtins.str]] = None,
                 translations: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TemplateSmsTranslationArgs', 'TemplateSmsTranslationArgsDict']]]]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TemplateSmsArgs.__new__(TemplateSmsArgs)

            if template is None and not opts.urn:
                raise TypeError("Missing required property 'template'")
            __props__.__dict__["template"] = template
            __props__.__dict__["translations"] = translations
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
        super(TemplateSms, __self__).__init__(
            'okta:index/templateSms:TemplateSms',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            template: Optional[pulumi.Input[builtins.str]] = None,
            translations: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TemplateSmsTranslationArgs', 'TemplateSmsTranslationArgsDict']]]]] = None,
            type: Optional[pulumi.Input[builtins.str]] = None) -> 'TemplateSms':
        """
        Get an existing TemplateSms resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] template: SMS default template
        :param pulumi.Input[Sequence[pulumi.Input[Union['TemplateSmsTranslationArgs', 'TemplateSmsTranslationArgsDict']]]] translations: Set of translations for a particular template.
        :param pulumi.Input[builtins.str] type: SMS template type
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TemplateSmsState.__new__(_TemplateSmsState)

        __props__.__dict__["template"] = template
        __props__.__dict__["translations"] = translations
        __props__.__dict__["type"] = type
        return TemplateSms(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def template(self) -> pulumi.Output[builtins.str]:
        """
        SMS default template
        """
        return pulumi.get(self, "template")

    @property
    @pulumi.getter
    def translations(self) -> pulumi.Output[Optional[Sequence['outputs.TemplateSmsTranslation']]]:
        """
        Set of translations for a particular template.
        """
        return pulumi.get(self, "translations")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[builtins.str]:
        """
        SMS template type
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['PolicyProfileEnrollmentAppsArgs', 'PolicyProfileEnrollmentApps']

@pulumi.input_type
class PolicyProfileEnrollmentAppsArgs:
    def __init__(__self__, *,
                 policy_id: pulumi.Input[builtins.str],
                 apps: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        The set of arguments for constructing a PolicyProfileEnrollmentApps resource.
        :param pulumi.Input[builtins.str] policy_id: ID of the enrollment policy.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] apps: List of app IDs to be added to this policy
        """
        pulumi.set(__self__, "policy_id", policy_id)
        if apps is not None:
            pulumi.set(__self__, "apps", apps)

    @property
    @pulumi.getter(name="policyId")
    def policy_id(self) -> pulumi.Input[builtins.str]:
        """
        ID of the enrollment policy.
        """
        return pulumi.get(self, "policy_id")

    @policy_id.setter
    def policy_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "policy_id", value)

    @property
    @pulumi.getter
    def apps(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        List of app IDs to be added to this policy
        """
        return pulumi.get(self, "apps")

    @apps.setter
    def apps(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "apps", value)


@pulumi.input_type
class _PolicyProfileEnrollmentAppsState:
    def __init__(__self__, *,
                 apps: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 default_policy_id: Optional[pulumi.Input[builtins.str]] = None,
                 policy_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering PolicyProfileEnrollmentApps resources.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] apps: List of app IDs to be added to this policy
        :param pulumi.Input[builtins.str] default_policy_id: ID of the Default Enrollment Policy. This policy is used as a policy to re-assign apps to when they are unassigned from this one
        :param pulumi.Input[builtins.str] policy_id: ID of the enrollment policy.
        """
        if apps is not None:
            pulumi.set(__self__, "apps", apps)
        if default_policy_id is not None:
            pulumi.set(__self__, "default_policy_id", default_policy_id)
        if policy_id is not None:
            pulumi.set(__self__, "policy_id", policy_id)

    @property
    @pulumi.getter
    def apps(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        List of app IDs to be added to this policy
        """
        return pulumi.get(self, "apps")

    @apps.setter
    def apps(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "apps", value)

    @property
    @pulumi.getter(name="defaultPolicyId")
    def default_policy_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ID of the Default Enrollment Policy. This policy is used as a policy to re-assign apps to when they are unassigned from this one
        """
        return pulumi.get(self, "default_policy_id")

    @default_policy_id.setter
    def default_policy_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "default_policy_id", value)

    @property
    @pulumi.getter(name="policyId")
    def policy_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ID of the enrollment policy.
        """
        return pulumi.get(self, "policy_id")

    @policy_id.setter
    def policy_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "policy_id", value)


@pulumi.type_token("okta:index/policyProfileEnrollmentApps:PolicyProfileEnrollmentApps")
class PolicyProfileEnrollmentApps(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 apps: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 policy_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Manages Profile Enrollment Policy Apps
        > **WARNING:** This feature is only available as a part of the Identity Engine. Contact support for further information.
        This resource allows you to manage the apps in the Profile Enrollment Policy.
        **Important Notes:**
         - Default Enrollment Policy can not be used in this resource since it is used as a policy to re-assign apps to when they are unassigned from this one.
         - When re-assigning the app to another policy, please use 'depends_on' in the policy to which the app will be assigned. This is necessary to avoid
             unexpected behavior, since if the app is unassigned from the policy it is just assigned to the 'Default' one.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.policy.get_policy(name="My Policy",
            type="PROFILE_ENROLLMENT")
        test = okta.app.get_app(label="My App")
        example_policy_profile_enrollment_apps = okta.PolicyProfileEnrollmentApps("example",
            policy_id=example_okta_policy["id"],
            apps=[id])
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/policyProfileEnrollmentApps:PolicyProfileEnrollmentApps example <policy_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] apps: List of app IDs to be added to this policy
        :param pulumi.Input[builtins.str] policy_id: ID of the enrollment policy.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PolicyProfileEnrollmentAppsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages Profile Enrollment Policy Apps
        > **WARNING:** This feature is only available as a part of the Identity Engine. Contact support for further information.
        This resource allows you to manage the apps in the Profile Enrollment Policy.
        **Important Notes:**
         - Default Enrollment Policy can not be used in this resource since it is used as a policy to re-assign apps to when they are unassigned from this one.
         - When re-assigning the app to another policy, please use 'depends_on' in the policy to which the app will be assigned. This is necessary to avoid
             unexpected behavior, since if the app is unassigned from the policy it is just assigned to the 'Default' one.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.policy.get_policy(name="My Policy",
            type="PROFILE_ENROLLMENT")
        test = okta.app.get_app(label="My App")
        example_policy_profile_enrollment_apps = okta.PolicyProfileEnrollmentApps("example",
            policy_id=example_okta_policy["id"],
            apps=[id])
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/policyProfileEnrollmentApps:PolicyProfileEnrollmentApps example <policy_id>
        ```

        :param str resource_name: The name of the resource.
        :param PolicyProfileEnrollmentAppsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PolicyProfileEnrollmentAppsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 apps: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 policy_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PolicyProfileEnrollmentAppsArgs.__new__(PolicyProfileEnrollmentAppsArgs)

            __props__.__dict__["apps"] = apps
            if policy_id is None and not opts.urn:
                raise TypeError("Missing required property 'policy_id'")
            __props__.__dict__["policy_id"] = policy_id
            __props__.__dict__["default_policy_id"] = None
        super(PolicyProfileEnrollmentApps, __self__).__init__(
            'okta:index/policyProfileEnrollmentApps:PolicyProfileEnrollmentApps',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            apps: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            default_policy_id: Optional[pulumi.Input[builtins.str]] = None,
            policy_id: Optional[pulumi.Input[builtins.str]] = None) -> 'PolicyProfileEnrollmentApps':
        """
        Get an existing PolicyProfileEnrollmentApps resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] apps: List of app IDs to be added to this policy
        :param pulumi.Input[builtins.str] default_policy_id: ID of the Default Enrollment Policy. This policy is used as a policy to re-assign apps to when they are unassigned from this one
        :param pulumi.Input[builtins.str] policy_id: ID of the enrollment policy.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PolicyProfileEnrollmentAppsState.__new__(_PolicyProfileEnrollmentAppsState)

        __props__.__dict__["apps"] = apps
        __props__.__dict__["default_policy_id"] = default_policy_id
        __props__.__dict__["policy_id"] = policy_id
        return PolicyProfileEnrollmentApps(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def apps(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        List of app IDs to be added to this policy
        """
        return pulumi.get(self, "apps")

    @property
    @pulumi.getter(name="defaultPolicyId")
    def default_policy_id(self) -> pulumi.Output[builtins.str]:
        """
        ID of the Default Enrollment Policy. This policy is used as a policy to re-assign apps to when they are unassigned from this one
        """
        return pulumi.get(self, "default_policy_id")

    @property
    @pulumi.getter(name="policyId")
    def policy_id(self) -> pulumi.Output[builtins.str]:
        """
        ID of the enrollment policy.
        """
        return pulumi.get(self, "policy_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'HookHeader',
]

@pulumi.output_type
class HookHeader(dict):
    def __init__(__self__, *,
                 key: Optional[builtins.str] = None,
                 value: Optional[builtins.str] = None):
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[builtins.str]:
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> Optional[builtins.str]:
        return pulumi.get(self, "value")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetEmailCustomizationsResult',
    'AwaitableGetEmailCustomizationsResult',
    'get_email_customizations',
    'get_email_customizations_output',
]

@pulumi.output_type
class GetEmailCustomizationsResult:
    """
    A collection of values returned by getEmailCustomizations.
    """
    def __init__(__self__, brand_id=None, email_customizations=None, id=None, template_name=None):
        if brand_id and not isinstance(brand_id, str):
            raise TypeError("Expected argument 'brand_id' to be a str")
        pulumi.set(__self__, "brand_id", brand_id)
        if email_customizations and not isinstance(email_customizations, list):
            raise TypeError("Expected argument 'email_customizations' to be a list")
        pulumi.set(__self__, "email_customizations", email_customizations)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if template_name and not isinstance(template_name, str):
            raise TypeError("Expected argument 'template_name' to be a str")
        pulumi.set(__self__, "template_name", template_name)

    @property
    @pulumi.getter(name="brandId")
    def brand_id(self) -> builtins.str:
        """
        Brand ID
        """
        return pulumi.get(self, "brand_id")

    @property
    @pulumi.getter(name="emailCustomizations")
    def email_customizations(self) -> Sequence['outputs.GetEmailCustomizationsEmailCustomizationResult']:
        """
        List of `EmailCustomization` belonging to the named email template of the brand in the organization
        """
        return pulumi.get(self, "email_customizations")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="templateName")
    def template_name(self) -> builtins.str:
        """
        Template Name
        """
        return pulumi.get(self, "template_name")


class AwaitableGetEmailCustomizationsResult(GetEmailCustomizationsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEmailCustomizationsResult(
            brand_id=self.brand_id,
            email_customizations=self.email_customizations,
            id=self.id,
            template_name=self.template_name)


def get_email_customizations(brand_id: Optional[builtins.str] = None,
                             template_name: Optional[builtins.str] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEmailCustomizationsResult:
    """
    Get the email customizations of an email template belonging to a brand in an Okta organization.


    :param builtins.str brand_id: Brand ID
    :param builtins.str template_name: Template Name
    """
    __args__ = dict()
    __args__['brandId'] = brand_id
    __args__['templateName'] = template_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getEmailCustomizations:getEmailCustomizations', __args__, opts=opts, typ=GetEmailCustomizationsResult).value

    return AwaitableGetEmailCustomizationsResult(
        brand_id=pulumi.get(__ret__, 'brand_id'),
        email_customizations=pulumi.get(__ret__, 'email_customizations'),
        id=pulumi.get(__ret__, 'id'),
        template_name=pulumi.get(__ret__, 'template_name'))
def get_email_customizations_output(brand_id: Optional[pulumi.Input[builtins.str]] = None,
                                    template_name: Optional[pulumi.Input[builtins.str]] = None,
                                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetEmailCustomizationsResult]:
    """
    Get the email customizations of an email template belonging to a brand in an Okta organization.


    :param builtins.str brand_id: Brand ID
    :param builtins.str template_name: Template Name
    """
    __args__ = dict()
    __args__['brandId'] = brand_id
    __args__['templateName'] = template_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getEmailCustomizations:getEmailCustomizations', __args__, opts=opts, typ=GetEmailCustomizationsResult)
    return __ret__.apply(lambda __response__: GetEmailCustomizationsResult(
        brand_id=pulumi.get(__response__, 'brand_id'),
        email_customizations=pulumi.get(__response__, 'email_customizations'),
        id=pulumi.get(__response__, 'id'),
        template_name=pulumi.get(__response__, 'template_name')))
